* Replikationsfile für den Artikel "Distanz zur Grenze als Indikator für den Erfolg der AfD bei der Bundestagswahl 2017 in Bayern?"
* erschienen in Zeitschrift für Vergleichende Politikwissenschaft, DOI: 10.1007/s12286-018-0395-8
* Autoren: Sebastian Jäckle, Uwe Wagschal und Andreas Kattler 

* Pfad für alle Dateien setzen 
  cd "...\Distanz zur Grenze Replikation"
  
	*version 13	
	clear all
	set matsize 11000
	set more off 
	
* Abbildung 1: Boxplots Wahlkreisergebnisse AfD Bundesweit
	import excel "BTWahl 2017 Ergebnisse Wahlkreise.xlsx", sheet("Tabelle1") firstrow
	
	gen dif_afd_spd = AfDZweitstimmen - SPDZweitstimmen
	label variable AfDZweitstimmen "AfD Zweitstimmenanteil in Prozent" 
	label variable dif_afd_spd "Differenz Zweitstimmenanteil AfD - SPD in Prozent"
	gen cdu_csu = CDUZweitstimmen + CSUZweitstimmen
	gen dif_afd_cducsu = AfDZweitstimmen - cdu_csu
	label variable dif_afd_cducsu "Differenz Zweitstimmenanteil AfD - CDU/CSU in Prozent"
	egen median_afd = median(AfDZweitstimmen), by(Land)
	
	#delimit ;
	graph box AfD dif_afd_spd, 
		over(Land, sort(median_afd) label(angle(30))) 
		scale(0.6)  
		aspectratio(0.4)  
		ylabel(#7) 
		graphregion(color(white)) 
		bgcolor(white);
	#delimit cr
	graph save abbildung_1, replace 

	clear all

* Voranalyse
	* Daten einlesen
	use "BTW17_Wahlkreisdata.dta", clear
	replace WestOST_numerisch = 0 if WestOST_numerisch ==1
	replace WestOST_numerisch = 1 if WestOST_numerisch ==2
	gen alter_ueber_60 = alt6074 + HD
	replace Bruttoinlandsprodukt2014je = Bruttoinlandsprodukt2014je/10000
	
	label variable AFDprozWk "AfD Zweitstimmenanteil in Prozent"
	label variable WestOST_numerisch "ostdeutscher Wahlkreis"
	label variable Grenzwahlkreis "Grenzwahlkreis im Süden oder Osten"
	label variable Unternehmensregister2014Hand "Handwerksunternehmen (je 1000 Einwohner)"
	label variable SozpflB_Prodgewerbe "Sozialversicherungspflichtig Beschäftigte im produzierenden Gewerbe in %"
	label variable alt6074 "Anteil Bevölkerung im Alter 60-74 Jahren in %"
	label variable alter_ueber_60 "Anteil Bevölkerung über 60 Jahre in %"
	label variable Bruttoinlandsprodukt2014je "Bruttoinlandsprodukt je Einwohner 2014 in 10.000 Euro"
	label variable ArbeitslosenquoteMrz201715 "Arbeitslosenquote der 15 bis unter 20 Jährigen in %"
	
	* Modell A: Gesamtmodell
	reg AFDprozWk WestOST_numerisch Grenzwahlkreis Unternehmensregister2014Hand  SozpflB_Prodgewerbe  alter_ueber_60 Bruttoinlandsprodukt2014je  ArbeitslosenquoteMrz201715 , 
	hettest
	*--> Chi2 = 51.15 --> robuste Standardfehler notwendig 
	vif
	* Vif max = 3.02 --> keine Multikollinearität
	reg AFDprozWk WestOST_numerisch Grenzwahlkreis Unternehmensregister2014Hand  SozpflB_Prodgewerbe  alter_ueber_60 Bruttoinlandsprodukt2014je  ArbeitslosenquoteMrz201715 , robust
	est tab, b se stats(r2_a)
	vif
	est store model_1
	
	*Modell B: Westdtl. inkl. Berlin
	reg AFDprozWk WestOST_numerisch Grenzwahlkreis Unternehmensregister2014Hand  SozpflB_Prodgewerbe  alter_ueber_60 Bruttoinlandsprodukt2014je  ArbeitslosenquoteMrz201715  if WestOST_BerlinistWest == "Westdeutschland"
	hettest
	*--> robust standard errors notwendig
	reg AFDprozWk WestOST_numerisch Grenzwahlkreis Unternehmensregister2014Hand  SozpflB_Prodgewerbe  alter_ueber_60 Bruttoinlandsprodukt2014je  ArbeitslosenquoteMrz201715  if WestOST_BerlinistWest == "Westdeutschland", robust
	est tab, b se stats(r2_a)
	vif
	*--> VIF Max = 2,35 --> keine Multikollinearität
	est store model_2
	
	* Modell C: Ostdtl
	reg AFDprozWk WestOST_numerisch Grenzwahlkreis Unternehmensregister2014Hand  SozpflB_Prodgewerbe  alter_ueber_60 Bruttoinlandsprodukt2014je  ArbeitslosenquoteMrz201715   if WestOST_BerlinistWest == "Ostdeutschland" 
	hettest
	* Chi2 = 0.98 --> keine robusten Standardfehler notwendig
	vif
	* VIF Max = 5.49 bei Unternehmensregister2014Hand --> 
	reg AFDprozWk WestOST_numerisch Grenzwahlkreis  Unternehmensregister2014Hand SozpflB_Prodgewerbe  alter_ueber_60  Bruttoinlandsprodukt2014je ArbeitslosenquoteMrz201715  if WestOST_BerlinistWest == "Ostdeutschland"
	est tab, b se stats(r2_a)
	est store model_3
	
	*Tabelle 2
	outreg2 [model_1 model_2  model_3] using table_1,  addstat(Adjusted R-squared, e(r2_a), F test,e(F)) word  label replace
	
	clear all

* Hauptanalyse Daten einlesen
	insheet using "afd_in_bayern_2017.csv", delimiter(",")

* Daten für Analyse aufbereiten

	** 	Zweitstimmen in Prozent 2017
	gen proz_zs_csu_17 = zs_csu_17/zs_gueltige_17*100
	gen proz_zs_spd_17 = zs_spd_17/zs_gueltige_17*100
	gen proz_zs_green_17 = zs_green_17/zs_gueltige_17*100
	gen proz_zs_fdp_17 = zs_fdp_17/zs_gueltige_17*100
	gen proz_zs_afd_17 = zs_afd_17/zs_gueltige_17*100
	gen proz_zs_linke_17 = zs_linke_17/zs_gueltige_17*100
	gen proz_zs_fw_17 = zs_fw_17/zs_gueltige_17*100
	gen proz_zs_pirat_17 = zs_pirat_17/zs_gueltige_17*100
	gen proz_zs_oedp_17 = zs_oedp_17/zs_gueltige_17*100
	gen proz_zs_bp_17 = zs_bp_17/zs_gueltige_17*100
	gen proz_zs_npd_17 = zs_npd_17/zs_gueltige_17*100
	gen proz_zs_tier_17 = zs_tier_17/zs_gueltige_17*100
	gen proz_zs_mlpd_17 = zs_mlpd_17/zs_gueltige_17*100
	gen proz_zs_bueso_17 = zs_bueso_17/zs_gueltige_17*100
	*gen proz_zs_bge_17 = zs_bge_17/zs_gueltige_17*100
	gen proz_zs_dib_17 = zs_dib_17/zs_gueltige_17*100
	gen proz_zs_dkp_17 = zs_dkp_17/zs_gueltige_17*100
	gen proz_zs_dm_17 = zs_dm_17/zs_gueltige_17*100
	gen proz_zs_diepartei_17 = zs_diepartei_17/zs_gueltige_17*100
	gen proz_zs_gesundheit_17 = zs_gesundheit_17/zs_gueltige_17*100
	gen proz_zs_vpartei_17 = zs_vpartei_17/zs_gueltige_17*100

	** Zweitstimmen in Prozent 2013
	gen proz_zs_csu_13 = zs_csu_13/zs_gueltige_13*100
	gen proz_zs_spd_13 = zs_spd_13/zs_gueltige_13*100
	gen proz_zs_fdp_13 = zs_fdp_13/zs_gueltige_13*100
	gen proz_zs_linke_13 = zs_linke_13/zs_gueltige_13*100
	gen proz_zs_green_13 = zs_green_13/zs_gueltige_13*100
	gen proz_zs_pirat_13 = zs_pirat_13/zs_gueltige_13*100
	gen proz_zs_npd_13 = zs_npd_13/zs_gueltige_13*100
	gen proz_zs_tier_13 = zs_tier_13/zs_gueltige_13*100
	gen proz_zs_rep_13 = zs_rep_13/zs_gueltige_13*100
	gen proz_zs_oedp_13 = zs_oedp_13/zs_gueltige_13*100
	gen proz_zs_familie_13 = zs_familie_13/zs_gueltige_13*100
	gen proz_zs_buendnis21_13 = zs_buendnis21_13/zs_gueltige_13*100
	gen proz_zs_rentner_13 = zs_rentner_13/zs_gueltige_13*100
	gen proz_zs_bp_13 = zs_bp_13/zs_gueltige_13*100
	gen proz_zs_pbc_13 = zs_pbc_13/zs_gueltige_13*100
	gen proz_zs_bueso_13 = zs_bueso_13/zs_gueltige_13*100
	gen proz_zs_violette_13 = zs_violette_13/zs_gueltige_13*100
	gen proz_zs_mlpd_13 = zs_mlpd_13/zs_gueltige_13*100
	gen proz_zs_volksabstimmung_13 = zs_volksabstimmung_13/zs_gueltige_13*100
	gen proz_zs_psg_13 = zs_psg_13/zs_gueltige_13*100
	gen proz_zs_afd_13 = zs_afd_13/zs_gueltige_13*100
	gen proz_zs_big_13 = zs_big_13/zs_gueltige_13*100
	gen proz_zs_prodeutschland_13 = zs_prodeutschland_13/zs_gueltige_13*100
	gen proz_zs_dierechte_13 = zs_dierechte_13/zs_gueltige_13*100
	gen proz_zs_diefrauen_13 = zs_diefrauen_13/zs_gueltige_13*100
	gen proz_zs_fw_13 = zs_fw_13/zs_gueltige_13*100
	gen proz_zs_nichtwaehler_13 = zs_nichtwaehler_13/zs_gueltige_13*100
	gen proz_zs_vernunft_13 = zs_vernunft_13/zs_gueltige_13*100
	
	** Stärke rechter Parteien bei BT-Wahl 2013
	gen proz_zs_rechteparteien_13 = proz_zs_npd_13 + proz_zs_rep_13 + proz_zs_afd_13 + proz_zs_prodeutschland_13 + proz_zs_dierechte_13

	**Kriminalitätsdaten pro  Einwohner 2016
	gen st_rel_16 = st_abs_16 / einwohner_kreis_15 * 100000
	gen wohnungsdiebstahl_rel_16 = wohnungsdiebstahl_abs_16 / einwohner_kreis_15 * 100000
	gen diebstahl_rel_16 = diebstahl_abs_16 / einwohner_kreis_15 * 100000
	gen kfzdiebstahl_rel_16 = kfzdiebstahl_abs_16 / einwohner_kreis_15 * 100000
	gen mord_rel_16 = mord_abs_16 / einwohner_kreis_15 * 100000
	gen koerperverletzung_rel_16 = koerperverletzung_abs_16 / einwohner_kreis_15 * 100000
	gen raub_rel_16 = raub_abs_16 / einwohner_kreis_15 * 100000
	gen vergewaltigung_rel_16 = vergewaltigung_abs_16 / einwohner_kreis_15 * 100000
	
	**Kriminalitätsdaten pro  Einwohner 2015
	gen st_rel_15 = st_abs_15 / einwohner_kreis_15 * 100000
	gen wohnungsdiebstahl_rel_15 = wohnungsdiebstahl_abs_15 / einwohner_kreis_15 * 100000
	gen diebstahl_rel_15 = diebstahl_abs_15 / einwohner_kreis_15 * 100000
	gen kfzdiebstahl_rel_15 = kfzdiebstahl_abs_15 / einwohner_kreis_15 * 100000
	gen mord_rel_15 = mord_abs_15 / einwohner_kreis_15 * 100000
	gen koerperverletzung_rel_15 = koerperverletzung_abs_15 / einwohner_kreis_15 * 100000
	gen raub_rel_15 = raub_abs_15 / einwohner_kreis_15 * 100000
	gen vergewaltigung_rel_15 = vergewaltigung_abs_15 / einwohner_kreis_15 * 100000
	
	** Nichtdeutsche Tatverdächtige in % aller Tatverdächtigen
	gen ndtv_wohnungsdiebstahl_16 = tv_nd_wohnungsdiebstahl_16 / tv_wohnungsdiebstahl_16 *100
	gen ndtv_kfz_diebstahl_16 = tv_nd_kfz_diebstahl_16 / tv_kfz_diebstahl_16 *100
	gen ndtv_koerperverletzung_16 = tv_nd_koerperverletzung_16 / tv_koerperverletzung_16 *100
	gen ndtv_raub_16 = tv_nd_raub_16 / tv_raub_16 *100
	gen ndtv_straftaten_insgesamt_16 = tv_nd_straftaten_insgesamt_16 / tv_straftaten_insgesamt_16 *100
	gen ndtv_vergewaltigungen_16 = tv_nd_vergewaltigungen_16 / tv_vergewaltigungen_16 *100
	replace ndtv_vergewaltigungen_16 = 0 if ndtv_vergewaltigungen_16 ==.
	replace ndtv_wohnungsdiebstahl_16 = 0 if ndtv_wohnungsdiebstahl_16 ==.
	
	** Prozentuale Veränderung Kriminalitätsraten 2015 --> 2016 
	gen delta_st = (st_rel_16 - st_rel_15)/st_rel_15 * 100
	gen delta_wohnungsdiebstahl = (wohnungsdiebstahl_rel_16 - wohnungsdiebstahl_rel_15)/wohnungsdiebstahl_rel_15 * 100
	gen delta_diebstahl = (diebstahl_rel_16 - diebstahl_rel_15)/diebstahl_rel_15 * 100
	gen delta_kfzdiebstahl = (kfzdiebstahl_rel_16 - kfzdiebstahl_rel_15)/kfzdiebstahl_rel_15 * 100
	gen delta_mord = (mord_rel_16 - mord_rel_15)/mord_rel_15 * 100
	gen delta_koerperverletzung = (koerperverletzung_rel_16 - koerperverletzung_rel_15)/koerperverletzung_rel_15 * 100
	gen delta_raub = (raub_rel_16 - raub_rel_15)/raub_rel_15 * 100
	gen delta_vergewaltigung = (vergewaltigung_rel_16 - vergewaltigung_rel_15)/vergewaltigung_rel_15 *100
		
	** Wahlbeteiligung
	gen wahlbeteiligung_17 = waehler_17/wahlberechtigte_17

	** Arbeitslosenquote Gemeindeebene auf Basis der Arbeistlosenzahlen September 16 und September 17, standardisiert an den Beschäftigtenzahlen Juni 2016
	** Beschäftigte insgesamt
	gen beschaeftigte_16 = svpb_wohnort_16 + geb_ausschliesslich_16
	gen erwerbsfaehige_16 = beschaeftigte_16 + arbeitslose_sep_16
	gen alq_sep_16 = arbeitslose_sep_16 / erwerbsfaehige_16 *100
	
	gen erwerbsfaehige_17 = beschaeftigte_16 + arbeitslose_sep_17
	gen alq_sep_17 = arbeitslose_sep_17 / erwerbsfaehige_16 *100
	
	gen gebquote_16 = geb_ausschliesslich_16 / erwerbsfaehige_16 * 100
	
	** Großstadt > 100.000 Einwohner
	gen grossstadt = 0
	replace grossstadt = 1 if einwohner > 99999
	
	** Mittelstadt 20.000 - 99.999 Einwohner
	gen mittelstadt = 0
	replace mittelstadt = 1 if einwohner > 20000 & einwohner < 100000
	
	** Kleinstadt 5.000 - 19.999 Einwohner
	gen kleinstadt = 0
	replace kleinstadt = 1 if einwohner > 5000 & einwohner < 20000
	
	** Einkommen in 1000 Euro
	gen einkommen_einwohner_1000 = einkommen_einwohner/1000 
	
	** Männeranteil auf Gemeindeebene
	gen maenneranteil = einwohner_m/einwohner * 100

	** Distanzen in km
	replace distanz_bw = distanz_bw/1000
	replace distanz_he = distanz_he/1000
	replace distanz_th = distanz_th/1000
	replace distanz_sn = distanz_sn/1000
	replace distanz_cz = distanz_cz/1000
	replace distanz_aut = distanz_aut/1000
	replace distanz_ost = distanz_ost/1000
	replace distanz_west = distanz_west/1000
	replace distanz_grenze = distanz_grenze/1000
	
	*Distanzen logarithmiert
	gen log_distanz_bw = log(distanz_bw)
	gen log_distanz_he = log(distanz_he)
	gen log_distanz_th = log(distanz_th)
	gen log_distanz_sn = log(distanz_sn)
	gen log_distanz_cz = log(distanz_cz)
	gen log_distanz_aut = log(distanz_aut)
	gen log_distanz_ost = log(distanz_ost)
	gen log_distanz_west = log(distanz_west)
	gen log_distanz_grenze = log(distanz_grenze)
	
	* Alle UV und Kontrollvariabeln außer der Stadtgröße-Dummies am Gesamtmittelwert zentrieren
	sum distanz_bw
	gen c_distanz_bw = distanz_bw - r(mean)
	sum distanz_he
	gen c_distanz_he = distanz_he - r(mean)
	sum distanz_th
	gen c_distanz_th = distanz_th - r(mean)
	sum distanz_sn
	gen c_distanz_sn = distanz_sn - r(mean)
	sum distanz_cz
	gen c_distanz_cz = distanz_cz - r(mean)
	sum distanz_aut
	gen c_distanz_aut = distanz_aut - r(mean)
	sum distanz_ost
	gen c_distanz_ost = distanz_ost - r(mean)
	sum distanz_west
	gen c_distanz_west = distanz_west - r(mean)
	sum distanz_grenze
	gen c_distanz_grenze = distanz_grenze - r(mean)
	sum log_distanz_bw
	gen c_log_distanz_bw = log_distanz_bw - r(mean)
	sum log_distanz_he
	gen c_log_distanz_he = log_distanz_he - r(mean)
	sum log_distanz_th
	gen c_log_distanz_th = log_distanz_th - r(mean)
	sum log_distanz_sn
	gen c_log_distanz_sn = log_distanz_sn - r(mean)
	sum log_distanz_cz
	gen c_log_distanz_cz = log_distanz_cz - r(mean)
	sum log_distanz_aut
	gen c_log_distanz_aut = log_distanz_aut - r(mean)
	sum log_distanz_ost
	gen c_log_distanz_ost = log_distanz_ost - r(mean)
	sum log_distanz_west
	gen c_log_distanz_west = log_distanz_west - r(mean)
	sum log_distanz_grenze
	gen c_log_distanz_grenze = log_distanz_grenze - r(mean)
	sum proz_zs_rechteparteien_13
	gen c_proz_zs_rechteparteien_13 = proz_zs_rechteparteien_13 - r(mean)
	sum proz_zs_csu_13
	gen c_proz_zs_csu_13 = proz_zs_csu_13 - r(mean)
	sum wohnungsdiebstahl_rel_16
	gen c_wohnungsdiebstahl_rel_16 = wohnungsdiebstahl_rel_16 - r(mean)
	sum kfzdiebstahl_rel_16
	gen c_kfzdiebstahl_rel_16 = kfzdiebstahl_rel_16 - r(mean)
	sum raub_rel_16
	gen c_raub_rel_16 = raub_rel_16 - r(mean)
	sum koerperverletzung_rel_16
	gen c_koerperverletzung_rel_16 = koerperverletzung_rel_16 - r(mean)
	sum vergewaltigung_rel_16
	gen c_vergewaltigung_rel_16 = vergewaltigung_rel_16 - r(mean)
	sum ndtv_wohnungsdiebstahl_16
	gen c_ndtv_wohnungsdiebstahl_16 = ndtv_wohnungsdiebstahl_16 - r(mean)
	sum ndtv_kfz_diebstahl_16
	gen c_ndtv_kfz_diebstahl_16 = ndtv_kfz_diebstahl_16 - r(mean)
	sum ndtv_koerperverletzung_16
	gen c_ndtv_koerperverletzung_16 = ndtv_koerperverletzung_16 - r(mean)
	sum ndtv_raub_16
	gen c_ndtv_raub_16 = ndtv_raub_16 - r(mean)
	sum ndtv_vergewaltigungen_16
	gen c_ndtv_vergewaltigungen_16 = ndtv_vergewaltigungen_16 - r(mean)
	sum ndtv_straftaten_insgesamt_16
	gen c_ndtv_straftaten_insgesamt_16 = ndtv_straftaten_insgesamt_16 - r(mean)
	sum auslaenderanteil
	gen c_auslaenderanteil = auslaenderanteil - r(mean)
	sum abitur
	gen c_abitur = abitur - r(mean)
	sum ohne_hauptschulabschluss
	gen c_ohne_hauptschulabschluss = ohne_hauptschulabschluss - r(mean)
	sum bev_dichte
	gen c_bev_dichte = bev_dichte - r(mean)
	sum bev_alte
	gen c_bev_alte = bev_alte - r(mean)
	sum alq_sep_17
	gen c_alq_sep_17 = alq_sep_17 - r(mean)
	sum insolvenzen
	gen c_insolvenzen = insolvenzen - r(mean)
	sum einkommen_einwohner_1000
	gen c_einkommen_einwohner_1000 = einkommen_einwohner_1000 - r(mean)
	sum wanderungssaldo_maenner
	gen c_wanderungssaldo_maenner = wanderungssaldo_maenner - r(mean)
	sum wanderungssaldo_frauen
	gen c_wanderungssaldo_frauen = wanderungssaldo_frauen - r(mean)
	sum pflegebeduerftige
	gen c_pflegebeduerftige = pflegebeduerftige - r(mean)
	sum krankenhausbetten
	gen c_krankenhausbetten = krankenhausbetten - r(mean)
	sum gebquote_16
	gen c_gebquote_16 = gebquote_16 - r(mean)
	sum maenneranteil
	gen c_maenneranteil = maenneranteil - r(mean)
	sum delta_st
	gen c_delta_st = delta_st - r(mean)
	sum delta_wohnungsdiebstahl
	gen c_delta_wohnungsdiebstahl = delta_wohnungsdiebstahl - r(mean)
	sum delta_diebstahl
	gen c_delta_diebstahl = delta_diebstahl - r(mean)
	sum delta_kfzdiebstahl
	gen c_delta_kfzdiebstahl = delta_kfzdiebstahl - r(mean)
	sum delta_mord
	gen c_delta_mord = delta_mord - r(mean)
	sum delta_koerperverletzung
	gen c_delta_koerperverletzung = delta_koerperverletzung - r(mean)
	sum delta_raub
	gen c_delta_raub = delta_raub - r(mean)
	sum delta_vergewaltigung
	gen c_delta_vergewaltigung = delta_vergewaltigung - r(mean)
	
	* Variablen labeln
	label variable proz_zs_afd_17 							"Zweitstimmen AfD bei BT-Wahl 2017 in Gemeinde, in %"
	label variable distanz_bw 								"Distanz Grenze BW, in km"
	label variable distanz_he 								"Distanz Grenze HE, in km"
	label variable distanz_th 								"Distanz Grenze TH, in km"
	label variable distanz_sn 								"Distanz Grenze SN, in km"
	label variable distanz_cz 								"Distanz Grenze CZ, in km"
	label variable distanz_aut 								"Distanz Grenze AUT, in km"
	label variable distanz_ost 								"Distanz Grenze OstDtl, in km"
	label variable distanz_west 							"Distanz Grenze WestDtl, in km"
	label variable distanz_grenze 							"Distanz Grenze, in km"
	label variable log_distanz_bw 							"Distanz Grenze BW, in km (log)"
	label variable log_distanz_he 							"Distanz Grenze HE, in km (log)"
	label variable log_distanz_th 							"Distanz Grenze TH, in km (log)"
	label variable log_distanz_sn 							"Distanz Grenze SN, in km (log)"
	label variable log_distanz_cz 							"Distanz Grenze CZ, in km (log)"
	label variable log_distanz_aut 							"Distanz Grenze AUT, in km (log)"
	label variable log_distanz_ost 							"Distanz Grenze OstDtl, in km (log)"
	label variable log_distanz_west 						"Distanz Grenze WestDtl, in km (log)"
	label variable log_distanz_grenze 						"Distanz Grenze, in km (log)"
	label variable proz_zs_rechteparteien_13 				"Zweitstimmen rechte Parteien bei BT-Wahl 2013 in Gemeinde, in %"
	label variable proz_zs_csu_13 							"Zweitstimmen CSU bei BT-Wahl 2013 in Gemeinde, in %"
	label variable wohnungsdiebstahl_rel_16 				"Wohnungseinbrüche in Kreis 2016, pro 100.000 Einwohner"
	label variable kfzdiebstahl_rel_16 						"Autodiebstähle in Kreis 2016, pro 100.000 Einwohner"
	label variable raub_rel_16 								"Raubdelikte in Kreis 2016, pro 100.000 Einwohner"
	label variable koerperverletzung_rel_16 				"Körperverletzungen in Kreis 2016, pro 100.000 Einwohner"
	label variable vergewaltigung_rel_16 					"Vergewaltigungen und sexuelle Nötigungen in Kreis 2016, pro 100.000 Einwohner"
	label variable ndtv_wohnungsdiebstahl_16 				"Anteil nichtdt. Tatverdächtiger bei Wohnungseinbrüchen in Kreis 2016, in %"
	label variable ndtv_kfz_diebstahl_16 					"Anteil nichtdt Tatverdächtiger bei Autodiebstählen in Kreis 2016, in %"
	label variable ndtv_koerperverletzung_16 				"Anteil nichtdt Tatverdächtiger bei Körperverletzungen in Kreis 2016, in %"
	label variable ndtv_raub_16 							"Anteil nichtdt Tatverdächtiger bei Raubdelikten in Kreis 2016, in %"
	label variable ndtv_vergewaltigungen_16 				"Anteil nichtdt Tatverdächtiger bei Vergew. und sex. Nötigungen in Kreis 2016, in %"
	label variable ndtv_straftaten_insgesamt_16 			"Anteil nichtdt Tatverdächtiger an Straftaten insgesamt in Kreis 2016, in %"
	label variable auslaenderanteil 						"Ausländeranteil an Gesamtbevölkerung in Kreis 2015, in %"
	label variable abitur 									"Anteil Schulabgänger mit allgem. Hochschulreife in Kreis 2015, in %"
	label variable ohne_hauptschulabschluss 				"Anteil Schulabgänger ohne Hauptschulabschluss in Kreis 2015, in %"
	label variable bev_dichte 								"Bevölkerungsdichte in Kreis, Einwohner je qkm"
	label variable bev_alte 								"Bevölkerung 65 Jahre und älter in Kreis, in %"
	label variable alq_sep_17 								"Arbeitslosenquote September 2017, Gemeindeebene, in %"
	label variable insolvenzen 								"Unternehmensinsolvenzen 2015, je 10.000 st.-pfl. Untern."
	label variable einkommen_einwohner_1000 				"Verfügbares Einkommen je Einwohner in Kreis 2015, in 1000 Euro"
	label variable wanderungssaldo_maenner 					"Wanderungssaldo je 10 000 in Kreis 2015: Männer 18 bis 29 Jahre"
	label variable wanderungssaldo_frauen 					"Wanderungssaldo je 10 000 in Kreis 2015: Frauen 18 bis 29 Jahre"
	label variable pflegebeduerftige 						"Pflegebedürftige in Kreis 2015, je 1.000 Einwohner ab 65 Jahre"
	label variable krankenhausbetten 						"Krankenhausbetten in Kreis 2015, je 1.000 Einw."
	label variable gebquote_16 								"Anteil ausschl. geringf. Beschäftigter an Erwerbspersonen in Gemeinde 2016, in %"
	label variable grossstadt 								"Großstadt > 100.000 Einwohner"
	label variable mittelstadt 								"Mittelstadt > 20.000 & < 100.000 Einwohner"
	label variable kleinstadt								"Kleinstadt > 5.000 & < 20.000 Einwohner"
	label variable maenneranteil 							"Anteil Männer an Gesamtbevölkerung der Gemeinde zum 31.12.2016, in %"
	label variable delta_wohnungsdiebstahl					"Prozentuale Veränderung Wohnungseinbrüche in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable delta_kfzdiebstahl						"Prozentuale Veränderung Autodiebstähle in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable delta_raub								"Prozentuale Veränderung Raubdelikte in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable delta_koerperverletzung					"Prozentuale Veränderung Körperverletzung in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable delta_vergewaltigung						"Prozentuale Veränderung Vergew. und sex. Nötigung in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	
	* mittelwertzentrierte Variablen mit selben Label
	
	label variable c_distanz_bw 							"Distanz Grenze BW, in km"
	label variable c_distanz_he 							"Distanz Grenze HE, in km"
	label variable c_distanz_th 							"Distanz Grenze TH, in km"
	label variable c_distanz_sn 							"Distanz Grenze SN, in km"
	label variable c_distanz_cz 							"Distanz Grenze CZ, in km"
	label variable c_distanz_aut 							"Distanz Grenze AUT, in km"
	label variable c_distanz_ost 							"Distanz Grenze OstDtl, in km"
	label variable c_distanz_west 							"Distanz Grenze WestDtl, in km"
	label variable c_distanz_grenze 						"Distanz Grenze, in km"
	label variable c_log_distanz_bw 						"Distanz Grenze BW, in km (log)"
	label variable c_log_distanz_he 						"Distanz Grenze HE, in km (log)"
	label variable c_log_distanz_th 						"Distanz Grenze TH, in km (log)"
	label variable c_log_distanz_sn 						"Distanz Grenze SN, in km (log)"
	label variable c_log_distanz_cz 						"Distanz Grenze CZ, in km (log)"
	label variable c_log_distanz_aut 						"Distanz Grenze AUT, in km (log)"
	label variable c_log_distanz_ost 						"Distanz Grenze OstDtl, in km (log)"
	label variable c_log_distanz_west 						"Distanz Grenze WestDtl, in km (log)"
	label variable c_log_distanz_grenze 					"Distanz Grenze, in km (log)"
	label variable c_proz_zs_rechteparteien_13 				"Zweitstimmen rechte Parteien bei BT-Wahl 2013 in Gemeinde, in %"
	label variable c_proz_zs_csu_13 						"Zweitstimmen CSU bei BT-Wahl 2013 in Gemeinde, in %"
	label variable c_wohnungsdiebstahl_rel_16 				"Wohnungseinbrüche in Kreis 2016, pro 100.000 Einwohner"
	label variable c_kfzdiebstahl_rel_16 					"Autodiebstähle in Kreis 2016, pro 100.000 Einwohner"
	label variable c_raub_rel_16 							"Raubdelikte in Kreis 2016, pro 100.000 Einwohner"
	label variable c_koerperverletzung_rel_16 				"Körperverletzungen in Kreis 2016, pro 100.000 Einwohner"
	label variable c_vergewaltigung_rel_16 					"Vergewaltigungen und sexuelle Nötigungen in Kreis 2016, pro 100.000 Einwohner"
	label variable c_ndtv_wohnungsdiebstahl_16 				"Anteil nichtdt. Tatverdächtiger bei Wohnungseinbrüchen in Kreis 2016, in %"
	label variable c_ndtv_kfz_diebstahl_16 					"Anteil nichtdt Tatverdächtiger bei Autodiebstählen in Kreis 2016, in %"
	label variable c_ndtv_koerperverletzung_16 				"Anteil nichtdt Tatverdächtiger bei Körperverletzungen in Kreis 2016, in %"
	label variable c_ndtv_raub_16 							"Anteil nichtdt Tatverdächtiger bei Raubdelikten in Kreis 2016, in %"
	label variable c_ndtv_vergewaltigungen_16 				"Anteil nichtdt Tatverdächtiger bei Vergew. und sex. Nötigungen in Kreis 2016, in %"
	label variable c_ndtv_straftaten_insgesamt_16 			"Anteil nichtdt Tatverdächtiger an Straftaten insgesamt in Kreis 2016, in %"
	label variable c_auslaenderanteil 						"Ausländeranteil an Gesamtbevölkerung in Kreis 2015, in %"
	label variable c_abitur 								"Anteil Schulabgänger mit allgem. Hochschulreife in Kreis 2015, in %"
	label variable c_ohne_hauptschulabschluss 				"Anteil Schulabgänger ohne Hauptschulabschluss in Kreis 2015, in %"
	label variable c_bev_dichte 							"Bevölkerungsdichte in Kreis, Einwohner je qkm"
	label variable c_bev_alte 								"Bevölkerung 65 Jahre und älter in Kreis, in %"
	label variable c_alq_sep_17 							"Arbeitslosenquote September 2017, Gemeindeebene, in %"
	label variable c_insolvenzen 							"Unternehmensinsolvenzen 2015, je 10.000 st.-pfl. Untern."
	label variable c_einkommen_einwohner_1000 				"Verfügbares Einkommen je Einwohner in Kreis 2015, in 1000 Euro"
	label variable c_wanderungssaldo_maenner 				"Wanderungssaldo je 10 000 in Kreis 2015: Männer 18 bis 29 Jahre"
	label variable c_wanderungssaldo_frauen 				"Wanderungssaldo je 10 000 in Kreis 2015: Frauen 18 bis 29 Jahre"
	label variable c_pflegebeduerftige 						"Pflegebedürftige in Kreis 2015, je 1.000 Einwohner ab 65 Jahre"
	label variable c_krankenhausbetten 						"Krankenhausbetten in Kreis 2015, je 1.000 Einw."
	label variable c_gebquote_16 							"Anteil ausschl. geringf. Beschäftigter an Erwerbspersonen in Gemeinde 2016, in %"
	label variable c_maenneranteil 							"Anteil Männer an Gesamtbevölkerung der Gemeinde zum 31.12.2016, in %"
	label variable c_delta_wohnungsdiebstahl				"Prozentuale Veränderung Wohnungseinbrüche in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable c_delta_kfzdiebstahl						"Prozentuale Veränderung Autodiebstähle in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable c_delta_raub								"Prozentuale Veränderung Raubdelikte in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable c_delta_koerperverletzung				"Prozentuale Veränderung Körperverletzung in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	label variable c_delta_vergewaltigung					"Prozentuale Veränderung Vergew. und sex. Nötigung in Kreis pro 100.000 Einwohner von 2015 zu 2016"
	
	*Überblickstabelle der Variablen
	* Tabelle 3
	#delimit ;
	fsum 	proz_zs_afd_17   																																								/* AV Zweitstimmen AfD BT-Wahl 2017 */
			distanz_cz distanz_aut distanz_west distanz_ost 																																/* UV Distanz zur Grenze */
			log_distanz_cz log_distanz_aut log_distanz_west log_distanz_ost																													/* UV Distanz zur Grenze (logarithmiert) */
			abitur ohne_hauptschulabschluss bev_alte alq_sep_17 insolvenzen einkommen_einwohner_1000 wanderungssaldo_maenner pflegebeduerftige krankenhausbetten gebquote_16 				/* Kontrolle: Modernisierungsverlierer */
			auslaenderanteil 																																								/* Kontrolle: Kontakthypothese */
			wohnungsdiebstahl_rel_16 kfzdiebstahl_rel_16 raub_rel_16 koerperverletzung_rel_16 vergewaltigung_rel_16																			/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			delta_wohnungsdiebstahl delta_kfzdiebstahl delta_koerperverletzung delta_raub delta_vergewaltigung
			ndtv_wohnungsdiebstahl ndtv_kfz_diebstahl ndtv_raub ndtv_koerperverletzung ndtv_vergewaltigung
			proz_zs_rechteparteien_13 proz_zs_csu_13 																																		/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt bev_dichte maenneranteil, label;																															/* weitere Kontrollen */
	#delimit cr
	
	*Überblickstabelle der mittelwertzentrierten Variablen
	#delimit ;
	fsum 	proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut c_distanz_west c_distanz_ost 																																/* UV Distanz zur Grenze */
			c_log_distanz_cz c_log_distanz_aut c_log_distanz_west c_log_distanz_ost																													/* UV Distanz zur Grenze (logarithmiert) */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16  																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_delta_wohnungsdiebstahl c_delta_kfzdiebstahl c_delta_koerperverletzung c_delta_raub c_delta_vergewaltigung
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil, label;																													/* weitere Kontrollen */
	#delimit cr
	
* Mehrebenenmodelle

	** Mehrebenen-Nullmodell zur Berechnung des IKK mit Maximum Likelihood
	xtmixed proz_zs_afd_17 || kreisname:, variance  mle
	* --> IKK = 0.0006569/(0.0006569+0.000534) = 0.5516 --> 55,2 % der Gesamtvarianz geht auf Unterschiede zwischen den Kreisen zurück --> MEA angebracht

	** Mehrebenen-Nullmodell zur Berechnung des IKK mit Restricted Maximum Likelihood
	xtmixed proz_zs_afd_17 || kreisname:, variance reml
	* --> IKK = 0.0006656/(0.0006656+0.000534) = 0.5549 --> 55,5 % der Gesamtvarianz geht auf Unterschiede zwischen den Kreisen zurück --> MEA angebracht
est store ME_Nullmodell
		
	** Ausgabe der Residuen + deren Standardfehler auf Basis des Mehrebenennullmodells
	predict u0, reffects
	predict u0se, reses
	
	** Zur tabellarischen Ausgabe der Residuen für jeden Kreis einen Fall herausgreifen
	egen pickone = tag(kreisname)
	list kreisname key_kreis u0 u0se if pickone ==1
	
	** Marker Label für die beiden höchsten und die beiden niedrigsten Residuenwerte
	gen markerlabel = kreisname if key_kreis == 9272 | key_kreis == 9276
	
	** Plotten der Residuen
	sort u0
	gen u0rank = sum(pickone)
	serrbar u0 u0se u0rank if pickone ==1, scale(1.96) yline(0) mlabel(markerlabel)
	
	** Modell 1_lin nur Distanz cz und aut
	xtmixed proz_zs_afd_17 c_distanz_cz c_distanz_aut   || kreisname:, variance reml
	est store model_1_lin
	
	** Modell 1_log nur Log-Distanz cz und aut
	xtmixed proz_zs_afd_17 c_log_distanz_cz c_log_distanz_aut   || kreisname:, variance reml
	est store model_1_log
	
		
	** Modell 2_random intercept_lin volles Modell Distanz zu cz und aut
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: , variance reml;
	#delimit cr
	est store model_2_ri_lin
	
	*OLS für VIF
	#delimit ;
	reg 	proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil;																															/* weitere Kontrollen */ 
	#delimit cr
	vif

		** Modell 2_random slope_lin volles Modell Distanz zu cz und aut
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_distanz_cz c_distanz_aut, variance reml;
	#delimit cr
	est store model_2_rs_lin
	
	** mit Wanderungssaldo Frauen statt Männer
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_frauen c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_distanz_cz c_distanz_aut, variance reml;
	#delimit cr
	

	* Predictions für die jeweils eine Standardabweichung erhöht bei den signifikanten Variablen
	#delimit ;
	margins, 	at(c_distanz_cz = 67.98) 
				at(c_distanz_aut = 89.44)
				at(c_abitur = 8.15)
				at(c_ohne_hauptschulabschluss = 1.50)
				at(c_bev_alte = 1.78)
				at(c_alq_sep_17 = 1.02)
				at(c_pflegebeduerftige = 29.89)
				at(c_gebquote_16 = 1.94)
				at(c_kfzdiebstahl_rel_16 = 5.56)
				at(c_ndtv_wohnungsdiebstahl = 28.60)
				at(c_proz_zs_rechteparteien_13 = 1.35)
				at(c_proz_zs_csu_13 = 6.97)
				at(c_maenneranteil = 1.36);
	#delimit cr
	marginsplot, recast(scatter) yline(12.97) ytitle("Vorhergesagter Wert für AfD Zweitstimmenanteil" "bei BT-Wahl 2017 in %")
	
	* Test ob die Entfernung des multikollinearen Ausländeranteils etwas ändert
		#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
																																																	/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_distanz_cz c_distanz_aut, variance reml;
	#delimit cr
	est store model_2_rs_lin_2
	
	
		** Modell 2_random slope_lin volles Modell Distanz zu cz und aut (mit Kovarianz unstructured)
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_distanz_cz c_distanz_aut, variance reml covariance(unstructured);
	#delimit cr
	*--> covariance unstructured verbessert Modell nicht wirklich
	
	** Modell 2_random intercept_log volles Modell Log-Distanz zu cz und aut
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_log_distanz_cz c_log_distanz_aut  																																					/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: , variance reml;
	#delimit cr
	est store model_2_ri_log
	
	* OLS für VIF
	#delimit ;
	reg 	proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_log_distanz_cz c_log_distanz_aut  																																					/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil;																															/* weitere Kontrollen */ 
	#delimit cr
	vif
	
		** Modell 2_random slope_log volles Modell Log-Distanz zu cz und aut
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_log_distanz_cz c_log_distanz_aut  																																					/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_log_distanz_cz c_log_distanz_aut , variance reml;
	#delimit cr
	est store model_2_rs_log
	
	** Modell 3_ri_lin volles Modell Distanz zu Grenze nach Ostdeutschland (Sachsen und Thüringen) und nach Westdeutschland (Hessen und Baden-Württemberg) + Rechte und CSU-Ergebnisse 2013 (Pfadabhängigkeit)
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_ost c_distanz_west  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: , variance reml;
	#delimit cr
	est store model_3_ri_lin
	
	*OLS für VIF
	#delimit ;
	reg 	proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_ost c_distanz_west  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil;																															/* weitere Kontrollen */ 
	#delimit cr
	vif

		** Modell 3_rs_lin volles Modell Distanz zu Grenze nach Ostdeutschland (Sachsen und Thüringen) und nach Westdeutschland (Hessen und Baden-Württemberg) + Rechte und CSU-Ergebnisse 2013 (Pfadabhängigkeit)
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_ost c_distanz_west  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_distanz_ost c_distanz_west, variance reml;
	#delimit cr
	est store model_3_rs_lin
	
	** Modell 3_ri_log volles Modell Log-Distanz zu Grenze nach Ostdeutschland (Sachsen und Thüringen) und nach Westdeutschland (Hessen und Baden-Württemberg) + Rechte und CSU-Ergebnisse 2013 (Pfadabhängigkeit)
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_log_distanz_ost c_log_distanz_west  																																					/* UV Distanz zur Grenze (logarithmiert) */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: , variance reml;
	#delimit cr
	est store model_3_ri_log
	
	*OLS für VIF
	#delimit ;
	reg 	proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_log_distanz_ost c_log_distanz_west  																																					/* UV Distanz zur Grenze (logarithmiert) */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil;																															/* weitere Kontrollen */ 
	#delimit cr
	vif
	
		** Modell 3_rs_log volles Modell Log-Distanz zu Grenze nach Ostdeutschland (Sachsen und Thüringen) und nach Westdeutschland (Hessen und Baden-Württemberg) + Rechte und CSU-Ergebnisse 2013 (Pfadabhängigkeit)
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_log_distanz_ost c_log_distanz_west  																																					/* UV Distanz zur Grenze (logarithmiert) */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_wohnungsdiebstahl_rel_16 c_kfzdiebstahl_rel_16 c_raub_rel_16 c_koerperverletzung_rel_16 c_vergewaltigung_rel_16 																		/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_log_distanz_ost c_log_distanz_west, variance reml;
	#delimit cr
	est store model_3_rs_log
	
	*Tabelle 4
	outreg2 [ME_Nullmodell model_1_lin model_2_rs_lin model_3_rs_lin] using Tabelle_4_lin, word label replace
    
	* Tabelle A2 im Online Anhang 
	outreg2 [ME_Nullmodell model_1_log model_2_rs_log model_3_rs_log] using Tabelle_4_log, word label replace
	
	* Test ob Entfernen der leict multikolinearen Ausländerquote Ergebnis ändert --> ist nicht der Fall!
	outreg2 [model_2_rs_lin model_2_rs_lin_2] using Tabelle_Test_ausländeranteil, word label replace


	** Modell 2 mit Delta Kriminalitätsrate
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_delta_wohnungsdiebstahl c_delta_kfzdiebstahl c_delta_raub c_delta_koerperverletzung c_delta_vergewaltigung 																			/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_distanz_cz c_distanz_aut, variance reml;
	#delimit cr
	est store model_2_delta
	
	** Modell 2 mit Delta Kriminalitätsrate (random intercept für R-Quadrate)
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_cz c_distanz_aut  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_delta_wohnungsdiebstahl c_delta_kfzdiebstahl c_delta_raub c_delta_koerperverletzung c_delta_vergewaltigung 																			/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: , variance reml;
	#delimit cr
	
	** Modell 3 mit Delta Kriminalitätsrate
		#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_ost c_distanz_west  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_delta_wohnungsdiebstahl c_delta_kfzdiebstahl c_delta_raub c_delta_koerperverletzung c_delta_vergewaltigung 																			/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: c_distanz_ost c_distanz_west, variance reml;
	#delimit cr
	est store model_3_delta

	** Modell 3 mit Delta Kriminalitätsrate (random intercept für R-Quadrate)
	#delimit ;
	xtmixed proz_zs_afd_17   																																										/* AV Zweitstimmen AfD BT-Wahl 2017 */
			c_distanz_ost c_distanz_west  																																							/* UV Distanz zur Grenze */
			c_abitur c_ohne_hauptschulabschluss c_bev_alte c_alq_sep_17 c_insolvenzen c_einkommen_einwohner_1000 c_wanderungssaldo_maenner c_pflegebeduerftige c_krankenhausbetten c_gebquote_16 	/* Kontrolle: Modernisierungsverlierer */
			c_auslaenderanteil 																																										/* Kontrolle: Kontakthypothese */
			c_delta_wohnungsdiebstahl c_delta_kfzdiebstahl c_delta_raub c_delta_koerperverletzung c_delta_vergewaltigung 																			/* Kontrolle: rationaler Protest; Kriminalitätsstatistik */
			c_ndtv_wohnungsdiebstahl c_ndtv_kfz_diebstahl c_ndtv_raub c_ndtv_koerperverletzung c_ndtv_vergewaltigung
			c_proz_zs_rechteparteien_13 c_proz_zs_csu_13 																																			/* Kontrolle: Pfadabhängigkeit */
			grossstadt mittelstadt kleinstadt c_bev_dichte c_maenneranteil																															/* weitere Kontrollen */ 
			|| kreisname: , variance reml;
	#delimit cr
	
	* Tabelle A3 im Online Anhang
	outreg2 [model_2_delta model_3_delta] using Tabelle_Test_delta, word label replace

